'***********************************************************
'**
'** p16f81x.inc : PIC 16f81x specific definitions
'**
'** Copyright (c) 2004, Kyle A. York
'** All rights reserved
'**
'***********************************************************
'
' conventions:
'    PIC registers begin with a '_'
'    after any configuration register follow the configuration bits
'    at the moment, the names are used internally by the PICbsc
'    compiler, so do not change them!
'
' This defines the common bits for the p16f818/9
'
' Note: For PWM to work it is assumed that bit 12 (CCPMX) of the
'       configuration word (address $2007) if set which multiplexes
'       portb<2> with the CCP1 function (see _ccp1_mplex_reg below)
'
'
' bank0
'
BYTE VOLATILE _ind        @ $0000 [ALL]
BYTE VOLATILE _tmr0       @ $0001 [0,2]
BYTE VOLATILE _pcl        @ $0002 [ALL]
BYTE VOLATILE _status     @ $0003 [ALL]
  CONSTANT BYTE _irp    = 7
  CONSTANT BYTE _rp1    = 6
  CONSTANT BYTE _rp0    = 5
  CONSTANT BYTE _not_to = 4
  CONSTANT BYTE _not_pd = 3
  CONSTANT BYTE _z      = 2
  CONSTANT BYTE _dc     = 1
  CONSTANT BYTE _c      = 0
BYTE VOLATILE _fsr        @ $0004 [ALL]
BYTE VOLATILE _port(2)    @ $0005
BYTE VOLATILE _porta      @ $0005
BYTE VOLATILE _portb      @ $0006 [0,2]
BYTE VOLATILE _pclath     @ $000a [ALL]
BYTE VOLATILE _intcon     @ $000b [ALL]
  CONSTANT BYTE _gie  = 7
  CONSTANT BYTE _peie = 6
  CONSTANT BYTE _t0ie = 5
  CONSTANT BYTE _inte = 4
  CONSTANT BYTE _rbie = 3
  CONSTANT BYTE _t0if = 2
  CONSTANT BYTE _intf = 1
  CONSTANT BYTE _rbif = 0
BYTE VOLATILE _pir1       @ $000c
  CONSTANT BYTE _adif   = 6
  CONSTANT BYTE _sspif  = 3
  CONSTANT BYTE _ccp1if = 2
  CONSTANT BYTE _tmr2if = 1
  CONSTANT BYTE _tmr1if = 0
BYTE VOLATILE _pir2       @ $000d
  CONSTANT BYTE _eeif   = 4
WORD VOLATILE _tmr1       @ $000e ' all 16 bits of _tmr1[lh]
BYTE VOLATILE _tmr1l      @ $000e
BYTE VOLATILE _tmr1h      @ $000f
BYTE VOLATILE _t1con      @ $0010
  CONSTANT BYTE _t1ckps1    = 5
  CONSTANT BYTE _t1ckps0    = 4
  CONSTANT BYTE _t1oscen    = 3
  CONSTANT BYTE _not_t1sync = 2
  CONSTANT BYTE _t1insync   = 2
  CONSTANT BYTE _t1sync     = 2
  CONSTANT BYTE _tmr1cs     = 1
  CONSTANT BYTE _tmr1on     = 0
BYTE VOLATILE _tmr2       @ $0011
BYTE VOLATILE _t2con      @ $0012
  CONSTANT BYTE _toutps3 = 6
  CONSTANT BYTE _toutps2 = 5
  CONSTANT BYTE _toutps1 = 4
  CONSTANT BYTE _toutps0 = 3
  CONSTANT BYTE _tmr2on  = 2
  CONSTANT BYTE _t2ckps1 = 1
  CONSTANT BYTE _t2ckps0 = 0
BYTE VOLATILE _sspbuf     @ $0013
BYTE VOLATILE _sspcon     @ $0014 
  CONSTANT BYTE _wcol  = 7
  CONSTANT BYTE _sspov = 6
  CONSTANT BYTE _sspen = 5
  CONSTANT BYTE _ckp   = 4
  CONSTANT BYTE _sspm3 = 3
  CONSTANT BYTE _sspm2 = 2
  CONSTANT BYTE _sspm1 = 1
  CONSTANT BYTE _sspm0 = 0
WORD VOLATILE _ccpr1      @ $0015 ' all 16 bits of _ccpr1[lh]
BYTE VOLATILE _ccpr1l     @ $0015
BYTE VOLATILE _ccpr1h     @ $0016
BYTE VOLATILE _ccp1con    @ $0017
  CONSTANT BYTE _ccp1x  = 5
  CONSTANT BYTE _ccp1y  = 4
  CONSTANT BYTE _ccp1m3 = 3
  CONSTANT BYTE _ccp1m2 = 2
  CONSTANT BYTE _ccp1m1 = 1
  CONSTANT BYTE _ccp1m0 = 0
BYTE VOLATILE _adresh     @ $001e
BYTE VOLATILE _adcon0     @ $001f
  CONSTANT BYTE _adcs1     = 7
  CONSTANT BYTE _adcs0     = 6
  CONSTANT BYTE _chs2      = 5
  CONSTANT BYTE _chs1      = 4
  CONSTANT BYTE _chs0      = 3
  CONSTANT BYTE _go        = 2
  CONSTANT BYTE _not_done  = 2
  CONSTANT BYTE _go_done   = 2
  CONSTANT BYTE _adon      = 0
'
' bank1
'
BYTE VOLATILE _option_reg @ $0081
  CONSTANT BYTE _not_rbpu = 7
  CONSTANT BYTE _intedg   = 6
  CONSTANT BYTE _t0cs     = 5
  CONSTANT BYTE _t0se     = 4
  CONSTANT BYTE _psa      = 3
  CONSTANT BYTE _ps2      = 2
  CONSTANT BYTE _ps1      = 1
  CONSTANT BYTE _ps0      = 0
BYTE VOLATILE _tris(2)    @ $0085
BYTE VOLATILE _trisa      @ $0085
BYTE VOLATILE _trisb      @ $0086 [1,3]
BYTE VOLATILE _pie1       @ $008c
  CONSTANT BYTE _adie   = 6
  CONSTANT BYTE _sspie  = 3
  CONSTANT BYTE _ccp1ie = 2
  CONSTANT BYTE _tmr2ie = 1
  CONSTANT BYTE _tmr1ie = 0
BYTE VOLATILE _pie2       @ $008d
  CONSTANT BYTE _eeie   = 4
BYTE VOLATILE _pcon       @ $008e
  CONSTANT BYTE _not_por = 1
  CONSTANT BYTE _not_bor = 0
  CONSTANT BYTE _not_bo  = 0
BYTE VOLATILE _osccon     @ $008f
BYTE VOLATILE _osctune    @ $0090
BYTE VOLATILE _pr2        @ $0092
BYTE VOLATILE _sspadd     @ $0093
BYTE VOLATILE _sspstat    @ $0094
  CONSTANT BYTE _smp          = 7
  CONSTANT BYTE _cke          = 6
  CONSTANT BYTE _d            = 5
  CONSTANT BYTE _i2c_data     = 5
  CONSTANT BYTE _not_a        = 5
  CONSTANT BYTE _not_address  = 5
  CONSTANT BYTE _d_a          = 5
  CONSTANT BYTE _data_address = 5
  CONSTANT BYTE _p            = 4
  CONSTANT BYTE _i2c_stop     = 4
  CONSTANT BYTE _s            = 3
  CONSTANT BYTE _i2c_start    = 3
  CONSTANT BYTE _r            = 2
  CONSTANT BYTE _i2c_read     = 2
  CONSTANT BYTE _not_w        = 2
  CONSTANT BYTE _not_write    = 2
  CONSTANT BYTE _r_w          = 2
  CONSTANT BYTE _read_write   = 2
  CONSTANT BYTE _ua           = 1
  CONSTANT BYTE _bf           = 0
BYTE VOLATILE _adresl     @ $009e
BYTE VOLATILE _adcon1     @ $009f
  CONSTANT BYTE _adfm  = 7
  CONSTANT BYTE _pcfg3 = 3
  CONSTANT BYTE _pcfg2 = 2
  CONSTANT BYTE _pcfg1 = 1
  CONSTANT BYTE _pcfg0 = 0
'
' bank 2
'
BYTE VOLATILE _eedata     @ $010c
BYTE VOLATILE _eeadr      @ $010d
BYTE VOLATILE _eedath     @ $010e
BYTE VOLATILE _eeadrh     @ $010f
'
' bank 3
'
BYTE VOLATILE _eecon1     @ $018c
  CONSTANT BYTE _eepgd = 7
  CONSTANT BYTE _wrerr = 3
  CONSTANT BYTE _wren  = 2
  CONSTANT BYTE _wr    = 1
  CONSTANT BYTE _rd    = 0
BYTE VOLATILE _eecon2     @ $018d

'
' these are used when entering into the ISR.
' _isr_w *must* exist in all banks at the same offset. on PICs
' with a shared region at the top, it should be placed there.
'
BYTE VOLATILE _isr_w      @$007c [ALL]
BYTE VOLATILE _isr_status @$007e [ALL]
BYTE VOLATILE _isr_pclath @$007f [ALL]
'
' this is needed by the pic code
'
BYTE VOLATILE _loop       @$0020
'
'
'
'
' trisb<2> is multiplexed with the _ccp1 module; it's redefined
' here because other PICs multiplex different port/bit combinations
'
BYTE VOLATILE _ccp1_mplex_reg @ $0086 ' _trisb
CONSTANT BYTE _ccp1_mplex_bit = 2

pragma RESTART   $0  ' the restart (power on) vector
pragma INTERRUPT $4  ' the interrupt vector

